@@ -1,16 +1,19 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# Pod stripped from pm file by OODoc 2.03.
+# This code is part of distribution Mail-Message.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+
+package Mail::Message::Body;{
+our $VERSION = '3.017';
+}
 
 # Mail::Message::Body::Construct adds functionality to Mail::Message::Body
 
-package Mail::Message::Body;
-use vars '$VERSION';
-$VERSION = '3.003';
-
+use strict;
+use warnings;
 
 use Carp;
 use Mail::Message::Body::String;
